export declare type SimpleCallback = (error?: Error) => void;
export declare type SimpleResultCallback<T> = (error?: Error, data?: T) => void;
export declare type InitContextCallback = (error?: Error, context?: any) => void;
export declare type BoltEmitCallback = (data: any, stream_id: string, callback: SimpleCallback) => void;
export declare type SpoutNextCallback = (err: Error, data: any, stream_id: string) => void;
export interface IValidationOptions {
    config: any;
    exitOnError?: boolean;
    throwOnError?: boolean;
}
export interface ITopologyDefinition {
    general: ITopologyDefinitionGeneral;
    spouts: ITopologyDefinitionSpout[];
    bolts: ITopologyDefinitionBolt[];
    variables: any;
}
export interface ITopologyDefinitionGeneral {
    heartbeat: number;
    weight?: number;
    worker_affinity?: string[];
    pass_binary_messages?: boolean;
}
export interface ITopologyDefinitionSpout {
    name: string;
    type?: string;
    disabled?: boolean;
    working_dir: string;
    cmd: string;
    subtype?: string;
    telemetry_timeout?: number;
    init: any;
}
export interface ITopologyDefinitionBolt {
    name: string;
    type?: string;
    disabled?: boolean;
    working_dir: string;
    cmd: string;
    subtype?: string;
    telemetry_timeout?: number;
    inputs: ITopologyDefinitionBoltInput[];
    init: any;
    allow_parallel?: boolean;
}
export interface ITopologyDefinitionBoltInput {
    source: string;
    stream_id?: string;
    disabled?: boolean;
}
export interface IBolt {
    init(name: string, config: any, context: any, callback: SimpleCallback): any;
    heartbeat(): any;
    shutdown(callback: SimpleCallback): any;
    receive(data: any, stream_id: string, callback: SimpleCallback): any;
}
export interface ISpout {
    init(name: string, config: any, context: any, callback: SimpleCallback): any;
    heartbeat(): any;
    shutdown(callback: SimpleCallback): any;
    run(): any;
    pause(): any;
    next(callback: SpoutNextCallback): any;
}
export interface IParentMsg {
    cmd: ParentMsgCode;
    data: any;
}
export declare enum ParentMsgCode {
    init = 0,
    run = 1,
    pause = 2,
    ping = 3,
    shutdown = 4
}
export interface IChildMsg {
    cmd: ChildMsgCode;
    data: any;
}
export declare enum ChildMsgCode {
    response_init = 0,
    response_run = 1,
    response_pause = 2,
    response_ping = 3,
    response_shutdown = 4,
    error = 5
}
export declare enum ChildExitCode {
    exit_ok = 0,
    parent_disconnect = 1,
    parent_ping_timeout = 2,
    init_error = 10,
    pause_error = 20,
    run_error = 25,
    shutdown_notinit_error = 30,
    shutdown_internal_error = 40,
    shutdown_unlikely_error = 41,
    internal_error = 110,
    unhandeled_error = 999
}
/**
 * Constants for using distributed functionality.
 */
export declare const CONSTS: {
    LeaderMessages: {
        kill_topology: string;
        rebalance: string;
        set_disabled: string;
        set_enabled: string;
        shutdown: string;
        start_topologies: string;
        start_topology: string;
        stop_topologies: string;
        stop_topology: string;
    };
    LeadershipStatus: {
        ok: string;
        pending: string;
        vacant: string;
    };
    TopologyStatus: {
        error: string;
        running: string;
        unassigned: string;
        waiting: string;
    };
    WorkerLStatus: {
        candidate: string;
        leader: string;
        normal: string;
    };
    WorkerStatus: {
        alive: string;
        closing: string;
        dead: string;
        disabled: string;
        unloaded: string;
    };
};
export interface ILeadershipResultStatus {
    leadership: string;
}
export interface IWorkerStatus {
    name: string;
    status: string;
    lstatus: string;
    last_ping: number;
    last_ping_d: Date;
    pid: number;
}
export interface IWorkerStatusHistory {
    name: string;
    status: string;
    lstatus: string;
    ts: Date;
    pid: number;
}
export interface ITopologyStatus {
    uuid: string;
    status: string;
    worker: string;
    error: string;
    pid: number;
    weight: number;
    enabled: boolean;
    last_ping: number;
    last_ping_d: Date;
    worker_affinity: string[];
}
export interface ITopologyStatusHistory extends ITopologyStatus {
    ts: Date;
}
export interface IStorageResultMessage {
    cmd: string;
    content: any;
    created: Date;
}
export interface IStorageProperty {
    key: string;
    value: string | number | boolean;
}
export interface ITopologyInfoResponse extends ITopologyStatus {
    config: ITopologyDefinition;
}
export interface IMsgQueueItem {
    name: string;
    cmd: string;
    data: any;
    created: Date;
    valid_until: Date;
}
/**
 * Interface that needs to be implemented by all storage implementations.
 */
export interface ICoordinationStorage {
    getWorkerStatus(callback: SimpleResultCallback<IWorkerStatus[]>): any;
    getTopologyStatus(callback: SimpleResultCallback<ITopologyStatus[]>): any;
    getTopologiesForWorker(worker: string, callback: SimpleResultCallback<ITopologyStatus[]>): any;
    getMessages(name: string, callback: SimpleResultCallback<IStorageResultMessage[]>): any;
    getMessage(name: string, callback: SimpleResultCallback<IStorageResultMessage>): any;
    getTopologyInfo(uuid: string, callback: SimpleResultCallback<ITopologyInfoResponse>): any;
    getTopologyHistory(uuid: string, callback: SimpleResultCallback<ITopologyStatusHistory[]>): any;
    getWorkerHistory(name: string, callback: SimpleResultCallback<IWorkerStatusHistory[]>): any;
    registerWorker(name: string, callback: SimpleCallback): any;
    pingWorker(name: string, callback?: SimpleCallback): any;
    announceLeaderCandidacy(name: string, callback: SimpleCallback): any;
    checkLeaderCandidacy(name: string, callback: SimpleResultCallback<boolean>): any;
    assignTopology(uuid: string, worker: string, callback: SimpleCallback): any;
    setTopologyStatus(uuid: string, worker: string, status: string, error: string, callback: SimpleCallback): any;
    setTopologyPid(uuid: string, pid: number, callback: SimpleCallback): any;
    setWorkerStatus(worker: string, status: string, callback: SimpleCallback): any;
    setWorkerLStatus(worker: string, lstatus: string, callback: SimpleCallback): any;
    sendMessageToWorker(worker: string, cmd: string, content: any, valid_msec: number, callback: SimpleCallback): any;
    getMsgQueueContent(callback: SimpleResultCallback<IMsgQueueItem[]>): any;
    registerTopology(uuid: string, config: ITopologyDefinition, callback: SimpleCallback): any;
    disableTopology(uuid: string, callback: SimpleCallback): any;
    enableTopology(uuid: string, callback: SimpleCallback): any;
    stopTopology(uuid: string, callback: SimpleCallback): any;
    killTopology(uuid: string, callback: SimpleCallback): any;
    deleteTopology(uuid: string, callback: SimpleCallback): any;
    deleteWorker(name: string, callback: SimpleCallback): any;
    getProperties(callback: SimpleResultCallback<IStorageProperty[]>): any;
}
